@@ -16,7 +16,7 @@ def multcompCatplot(**kwargs):
     kwargs["data"]  = kwargs["data"].dropna();
     facet_vars = ["row","col","x","hue"]
     if "letterSize" not in kwargs:
-        kwargs["letterSize"] = 18
+        kwargs["letterSize"] = matplotlib.rcParams["font.size"]
     letterSize = kwargs["letterSize"]
     del kwargs["letterSize"]
     if "pointStyle" not in kwargs:
@@ -72,21 +72,30 @@ def multcompCatplot(**kwargs):
     if "custom_color" in kwargs:
         custom_color = kwargs["custom_color"]
         del kwargs["custom_color"]
+    
     if "addPoints" in kwargs:
+        coloredObject = "points"
         addPoints = kwargs["addPoints"]
         if addPoints and "hue" in kwargs:
             quit("Cannot use hue together with points")
         del kwargs["addPoints"]
     else:
+        coloredObject = "box"
         addPoints = False
-    if "pointSize" in kwargs:
-        pointSize = kwargs["pointSize"]
+    if "coloredObject" in kwargs:
+        coloredObject = kwargs["coloredObject"]
+        del kwargs["coloredObject"]
+    if "pointArgs" in kwargs:
+        pointArgs = kwargs["pointArgs"]
+        del kwargs["pointArgs"]
+    elif "pointSize" in kwargs:
+        kwargs["pointArgs"] = {"size": kwargs["pointSize"]}
         del kwargs["pointSize"]
     else:
-        pointSize = 5
+        pointArgs = {}
     g = sns.catplot(**kwargs)
     if addPoints:
-        g.map_dataframe(pointStyleStripplot, pointStyle=pointStyle, x=kwargs["x"], y=kwargs["y"], hue=custom_color[0], palette=custom_color[1], linewidth=1, size=pointSize)
+        g.map_dataframe(pointStyleStripplot, pointStyle=pointStyle, coloredObject=coloredObject, pointArgs=pointArgs, x=kwargs["x"], y=kwargs["y"], hue=custom_color[0], palette=custom_color[1])
     c = 0
     for ax in g.axes.ravel():
         for p in ax.get_children():
@@ -94,7 +103,7 @@ def multcompCatplot(**kwargs):
                 bbox = p.get_extents().transformed(ax.transData.inverted())
                 dataj, annotation = letters.pop(0)
                 data = json.loads(dataj)
-                if (not addPoints) and custom_color and (custom_color[0] in data) and (data[custom_color[0]] in custom_color[1]):
+                if coloredObject == "box" and custom_color and (custom_color[0] in data) and (data[custom_color[0]] in custom_color[1]):
                     p.set_facecolor(custom_color[1][data[custom_color[0]]])
                 else:
                     p.set_facecolor("white")
@@ -103,7 +112,7 @@ def multcompCatplot(**kwargs):
                 bbox = p.get_paths()[0].get_extents()
                 dataj, annotation = letters.pop(0)
                 data = json.loads(dataj)
-                if (not addPoints) and custom_color and (custom_color[0] in data) and (data[custom_color[0]] in custom_color[1]):
+                if coloredObject == "box" and custom_color and (custom_color[0] in data) and (data[custom_color[0]] in custom_color[1]):
                     p.set_facecolor(custom_color[1][data[custom_color[0]]])
                 else:
                     p.set_facecolor("white")
@@ -121,7 +130,17 @@ colors = {
 
 def pointStyleStripplot(*args, **kwargs):
     pointStyle = kwargs["pointStyle"]
+    coloredObject = kwargs["coloredObject"]
+    del kwargs["coloredObject"]
     del kwargs["pointStyle"]
+    if coloredObject == "box":
+        del kwargs["hue"]
+        del kwargs["palette"]
+        kwargs["edgecolor"] = "black"
+        kwargs["color"] = "white"
+    if "pointArgs" in kwargs:
+        kwargs.update(kwargs["pointArgs"])
+        del kwargs["pointArgs"]
     if not pointStyle:
         sns.stripplot(*args,**kwargs)
         return
